@@ -1,6 +1,6 @@
 /*******************************************************************
 *
-* This file is part of the KDE project "Bovo"
+* Copyright 2007  Aron Boström <c02ab@efd.lth.se>
 *
 * Bovo is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -23,9 +23,9 @@
 #include "view.h"
 
 // Qt Includes
-#include <QtGui/QColor>
+#include <QColor>
 #include <QGraphicsScene>
-#include <QtGui/QPalette>
+#include <QPalette>
 #include <QResizeEvent>
 
 // Bovo includes
